<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>BandpassDialog</name>
    <message>
        <location filename="bandpassdialog.ui" line="14"/>
        <source>Alignment</source>
        <translation>Alignement</translation>
    </message>
    <message>
        <location filename="bandpassdialog.ui" line="28"/>
        <source>Curve gain (dB)</source>
        <translation>Gain de la courbe (dB)</translation>
    </message>
    <message>
        <location filename="bandpassdialog.ui" line="57"/>
        <source>Curve ripple (0.7 = 0dB)</source>
        <translation>Oscillation de la courbe (0.7 = 0dB)</translation>
    </message>
</context>
<context>
    <name>ListDialog</name>
    <message>
        <location filename="listdialog.ui" line="17"/>
        <source>Please select an item</source>
        <translation>Veuillez sélectionner un item</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="24"/>
        <source>Loudspeaker</source>
        <translation>Haut-parleur</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="30"/>
        <source>number</source>
        <translation>nombre</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="56"/>
        <source>vendor</source>
        <translation>constructeur</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="73"/>
        <source>model</source>
        <translation>modèle</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="115"/>
        <location filename="mainwindow.ui" line="141"/>
        <location filename="mainwindow.ui" line="167"/>
        <location filename="mainwindow.ui" line="186"/>
        <location filename="mainwindow.ui" line="212"/>
        <location filename="mainwindow.ui" line="238"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="148"/>
        <location filename="mainwindow.ui" line="454"/>
        <location filename="mainwindow.ui" line="813"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="179"/>
        <source>Vas:</source>
        <translation>Vas :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="193"/>
        <location filename="mainwindow.ui" line="330"/>
        <location filename="mainwindow.ui" line="417"/>
        <location filename="mainwindow.ui" line="719"/>
        <location filename="mainwindow.ui" line="776"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="219"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="245"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="264"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="278"/>
        <source>Sealed enclosure</source>
        <translation>Enceinte close</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="281"/>
        <source>1st order filter</source>
        <translation>filtre du premier ordre</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="284"/>
        <source>Simple, safe enclosure good for several speakers.</source>
        <translation>Enceinte simple et sûre, bonne pour certains haut-parleurs.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="313"/>
        <source>Enclosure volume</source>
        <translation>Volume de l&apos;enceinte</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="368"/>
        <source>Ported enclosure</source>
        <translation>Enceinte à évent</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="371"/>
        <source>2nd order filter</source>
        <translation>filtre du second ordre</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="374"/>
        <source>Popular enclosure type to enhance bass for most speakers.</source>
        <translation>Type d&apos;enceinte réputé pour améliorer la réponse en basses pour la plupart des haut-parleurs.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="400"/>
        <source>Enclosure volume (Vb)</source>
        <translation>Volume de l&apos;enceinte (Vb)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="437"/>
        <source>Enclosure filter resonance (Fb)</source>
        <translation>Résonance de l&apos;enceinte (Fb)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="474"/>
        <source>Enclosure quality loss factor (Ql)</source>
        <translation>Facteur de qualité dû aux pertes de l&apos;enceinte (Ql)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="521"/>
        <location filename="mainwindow.ui" line="880"/>
        <source>Number of ports</source>
        <translation>Nombre d&apos;évents</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="538"/>
        <location filename="mainwindow.ui" line="897"/>
        <source>Port diameter</source>
        <translation>Diamètre d&apos;évent</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="555"/>
        <location filename="mainwindow.ui" line="618"/>
        <location filename="mainwindow.ui" line="658"/>
        <location filename="mainwindow.ui" line="914"/>
        <location filename="mainwindow.ui" line="957"/>
        <location filename="mainwindow.ui" line="997"/>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="575"/>
        <location filename="mainwindow.ui" line="934"/>
        <source>Slot port</source>
        <translation>Laminaire</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="595"/>
        <location filename="mainwindow.ui" line="947"/>
        <source>x</source>
        <translatorcomment>multiply sign</translatorcomment>
        <translation>x</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="638"/>
        <location filename="mainwindow.ui" line="977"/>
        <source>Port length</source>
        <translation>Longueur d&apos;évent</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="670"/>
        <source>Bandpass enclosure</source>
        <translation>Caisson passe-bande</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="673"/>
        <source>4th order filter</source>
        <translation>filtre du quatrième ordre</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="676"/>
        <source>Enclosure for subwoofer, mostly used in 2:1, 5:1 and 7:1 systems.</source>
        <translation>Enceinte pour subwoofer, souvent utilisée pour les systèmes 2:1, 5:1 et 7:1.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="702"/>
        <source>Sealed enclosure volume</source>
        <translation>Volume de l&apos;enceinte close</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="759"/>
        <source>Ported enclosure volume</source>
        <translation>Volume de l&apos;enceinte à évent</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="796"/>
        <source>Ported enclosure filter resonance</source>
        <translation>Résonance de l&apos;enceinte à évent</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="833"/>
        <source>Bandpass enclosure quality loss factor</source>
        <translation>Facteur de qualité dû aux pertes du caisson</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1022"/>
        <source>Project</source>
        <translation>Projet</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1035"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1039"/>
        <source>Ported alignments</source>
        <translation>Alignements avec évent</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1056"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1062"/>
        <source>Speaker</source>
        <translation>Haut-parleur</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1071"/>
        <source>Exports</source>
        <translation>Exports</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1110"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1115"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1121"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1132"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1137"/>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1140"/>
        <source>Print the current project</source>
        <translation>Imprime le projet</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1143"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1148"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1151"/>
        <source>Quit the application</source>
        <translation>Quitte l&apos;application</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1154"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1159"/>
        <location filename="mainwindow.cpp" line="1246"/>
        <source>About QSpeakers</source>
        <translation>À propos de QSpeakers</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1162"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1167"/>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1170"/>
        <source>New speaker parameters</source>
        <translation>Nouveau haut-parleur</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1173"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1178"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1181"/>
        <source>Search a speaker</source>
        <translation>Recherche un haut-parleur</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1186"/>
        <source>Optimize</source>
        <translation>Optimiser</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1189"/>
        <source>Optimize frequency response</source>
        <translation>Optimise la réponse en fréquence</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1192"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1197"/>
        <source>Modify</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1200"/>
        <source>Modify the current speaker</source>
        <translation>Modifie le haut-parleur</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1203"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1208"/>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1211"/>
        <source>Remove the current speaker</source>
        <translation>Retire le haut-parleur</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1216"/>
        <source>Bessel</source>
        <translation>Bessel</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1219"/>
        <source>Linear phase and fast transient response alignment</source>
        <translation>Alignement à phase linéaire et réponse en transitoire rapide</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1227"/>
        <source>Extended bass response with minimum ripple</source>
        <translation>Réponse étendue en grave avec un minimum d&apos;oscillation</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1235"/>
        <source>Boom box butterworth 4th order alignment</source>
        <translation>Alignement Butterworth du 4è ordre «Boom box»</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1243"/>
        <source>Super boom box butterworth 4th order alignment</source>
        <translation>Alignement Butterworth du 4è ordre «Super boom box»</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1264"/>
        <source>Undo</source>
        <translation>Défaire</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1267"/>
        <source>Undo action</source>
        <translation>Défaire</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1270"/>
        <source>Ctrl+U</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1278"/>
        <source>Redo</source>
        <translation>Refaire</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1281"/>
        <source>Redo action</source>
        <translation>Refaire</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1284"/>
        <source>Ctrl+R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1289"/>
        <source>3D OpenScad</source>
        <translation>OpenScad 3D</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1294"/>
        <source>2D OpenScad</source>
        <translation>OpenScad 2D</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1299"/>
        <source>Curve Plot</source>
        <translation>Courbe</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1304"/>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1248"/>
        <source>Zbinden M4</source>
        <translation>M4 Zbinden</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="108"/>
        <source>Spl:</source>
        <translation>Spl :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="122"/>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="134"/>
        <source>Fs:</source>
        <translation>Fs :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="160"/>
        <source>Qts:</source>
        <translation>Qts :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="205"/>
        <source>Dia:</source>
        <translation>Dia :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="231"/>
        <source>Z:</source>
        <translation>Z :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="257"/>
        <source>Vc:</source>
        <translation>Vc :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1251"/>
        <source>Moderate alignment (infinite baffle)</source>
        <translation>Alignement modéré (sur baffle infini)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1256"/>
        <source>Bandpass alignment</source>
        <translation>Alignement caisson passe-bande</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1224"/>
        <source>Legendre</source>
        <translation>Legendre</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1104"/>
        <source>Open...</source>
        <translation>Ouvrir...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1107"/>
        <source>Open a speaker project</source>
        <translation>Ouvre un projet</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1118"/>
        <source>Save the current project</source>
        <translation>Enregistre le projet</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1126"/>
        <source>Save copy...</source>
        <translation>Enregistrer une copie...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1129"/>
        <source>Save the current project in a copy</source>
        <translation>Enregistre une copie du projet</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1232"/>
        <source>Hoge BB4</source>
        <translation>BB4 Hoge</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1240"/>
        <source>Bullock SBB4</source>
        <translation>SBB4 Bullock</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="59"/>
        <source>Recently opened</source>
        <translation>Récemment ouvert</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="89"/>
        <source>Sealed volume frequency response</source>
        <translation>Réponse fréquentielle de l&apos;enceinte close</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="95"/>
        <source>Ported volume frequency response</source>
        <translation>Réponse fréquentielle de l&apos;enceinte à évent</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="101"/>
        <source>Bandpass volumes frequency response</source>
        <translation>Réponse fréquentielle du caisson passe-bande</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="197"/>
        <source>Export File</source>
        <translation>Exporter le fichier</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="197"/>
        <location filename="mainwindow.cpp" line="224"/>
        <source>QSpeakers project (*.qsp)</source>
        <translation>Projet QSpeakers (*.qsp)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="197"/>
        <source>untitled.qsp</source>
        <translation>sans_nom.qsp</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="216"/>
        <location filename="mainwindow.cpp" line="239"/>
        <location filename="mainwindow.cpp" line="357"/>
        <source>Project not saved</source>
        <translation>Projet non enregistré</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="217"/>
        <location filename="mainwindow.cpp" line="240"/>
        <source>Current project has not been saved. Continue anyway?</source>
        <translation>Le projet actuel n&apos;a pas été enregistré. Continuer quand-même ?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="224"/>
        <source>Import File</source>
        <translation>Importer un fichier</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="231"/>
        <location filename="mainwindow.cpp" line="249"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="231"/>
        <location filename="mainwindow.cpp" line="249"/>
        <source>Could not open project!</source>
        <translation>Impossible d&apos;ouvrir le projet !</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="358"/>
        <source>The current project has not been saved. Exit anyway?</source>
        <translation>Le projet actuel n&apos;a pas été enregistré. Quitter malgré tout ?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="622"/>
        <source>Export for Gnuplot</source>
        <translation>Exporter pour Gnuplot</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="622"/>
        <source>Gnuplot data (*.dat)</source>
        <translation>Données Gnuplot (*.dat)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="647"/>
        <source>Export for 3D OpenSCAD</source>
        <translation>Export 3D pour OpenSCAD</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="647"/>
        <location filename="mainwindow.cpp" line="673"/>
        <source>OpenSCAD script (*.scad)</source>
        <translation>Script OpenSCAD (*.scad)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="673"/>
        <source>Export for 2D OpenSCAD</source>
        <translation>Export 2D pour OpenSCAD</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1063"/>
        <source>Removal confirmation</source>
        <translation>Confirmation de la suppression</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1064"/>
        <source>Do you really want to remove this loudspeaker from the database?</source>
        <translation>Voulez-vous vraiment retirer ce haut-parleur de la base de données ?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1247"/>
        <source>QSpeakers version %1 (%2)

This program simulates common acoustical enclosures behaviour to help designing loudspeaker systems.

This program is free software, copyright (C) 2014 Benoît Rouits &lt;brouits@free.fr&gt; and released under the GNU General Public License version 3. It is delivered as is in the hope it can be useful, but with NO WARRANTY AT ALL.</source>
        <translation>QSpeakers version %1 (%2)

Ce programme simule le comportement d&apos;enceintes acoustiques classiques dans le but d&apos;aider à la conception de systèmes de haut-parleurs.

Ce programme est un logiciel libre, copyright (C) 2014 Benoît Rouits &lt;brouits@free.fr&gt; et publié sous la license Générale Publique GNU version 3. Il est délivré tel quel dans l&apos;espoir d&apos;être utile, mais SANS AUCUNE GARANTIE.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1382"/>
        <location filename="mainwindow.cpp" line="1439"/>
        <source>Unsaved speaker</source>
        <translation>Haut-parleur non enregistré</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1383"/>
        <location filename="mainwindow.cpp" line="1440"/>
        <source>Speaker driver %1 is not present in the database. Do you want to insert it before to continue?</source>
        <translation>Le haut-parleur %1 n&apos;est pas présent dans la base de données. Voulez-vous l&apos;insérer avant de continuer ?</translation>
    </message>
</context>
<context>
    <name>Plot</name>
    <message>
        <location filename="plot.cpp" line="257"/>
        <source>Frequency [Hz]</source>
        <translation>Fréquence [Hz]</translation>
    </message>
    <message>
        <location filename="plot.cpp" line="265"/>
        <source>Sound pressure [dB]</source>
        <translation>Pression sonore [dB]</translation>
    </message>
    <message>
        <location filename="plot.cpp" line="96"/>
        <location filename="plot.cpp" line="128"/>
        <location filename="plot.cpp" line="151"/>
        <source>%1 dB at %2 Hz</source>
        <translation>%1 dB à %2 Hz</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="propertiesdialog.ui" line="14"/>
        <source>Project Properties</source>
        <translation>Propriétés du projet</translation>
    </message>
    <message>
        <location filename="propertiesdialog.ui" line="20"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="propertiesdialog.ui" line="30"/>
        <source>Note</source>
        <translation>Note</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="bandpassbox.cpp" line="177"/>
        <source>Sealed Volume: %1 L</source>
        <translation>Volume Clos : %1 L</translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="178"/>
        <source>Ported Volume: %1 L</source>
        <translation>Volume avec évent : %1 L</translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="181"/>
        <location filename="portedbox.cpp" line="219"/>
        <source>Port Diameter: %1 cm</source>
        <translation>Diamètre Évent : %1 cm</translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="186"/>
        <location filename="portedbox.cpp" line="223"/>
        <source>Port Length: %1 cm</source>
        <translation>Longueur Évent : %1 cm</translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="187"/>
        <location filename="portedbox.cpp" line="224"/>
        <source>Port #: %1</source>
        <translation>Nombre Évent(s) : %1</translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="188"/>
        <location filename="portedbox.cpp" line="225"/>
        <source>Fb: %1 Hz</source>
        <translation>Fb : %1 Hz</translation>
    </message>
    <message>
        <location filename="portedbox.cpp" line="217"/>
        <location filename="sealedbox.cpp" line="54"/>
        <source>Volume: %1 L</source>
        <translation>Volume : %1 L</translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="183"/>
        <location filename="portedbox.cpp" line="221"/>
        <source>Slot port: %1 x %2 cm</source>
        <translation>Évent laminaire : %1 x %2 cm</translation>
    </message>
    <message>
        <location filename="system.cpp" line="91"/>
        <source>Loudspeaker(s): </source>
        <translation>Haut-parleur(s) : </translation>
    </message>
    <message>
        <location filename="system.cpp" line="98"/>
        <source>sealed</source>
        <translation>close</translation>
    </message>
    <message>
        <location filename="system.cpp" line="98"/>
        <source>ported</source>
        <translation>à évent</translation>
    </message>
    <message>
        <location filename="system.cpp" line="98"/>
        <source>bandpass</source>
        <translation>passe-bande</translation>
    </message>
    <message>
        <location filename="system.cpp" line="99"/>
        <source>Enclosure: </source>
        <translation>Enceinte : </translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="46"/>
        <source>optimizing sealed box</source>
        <translation>optimisation de l&apos;enceinte close</translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="54"/>
        <source>applying &apos;max flat&apos; alignment</source>
        <translation>application de l&apos;alignement &apos;max flat&apos;</translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="67"/>
        <source>applying Bessel alignment</source>
        <translation>application de l&apos;alignement Bessel</translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="75"/>
        <source>applying Bullock alignment</source>
        <translation>application de l&apos;alignement Bullock</translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="82"/>
        <source>applying Keele &amp; Hoge alignment</source>
        <translation>application de l&apos;alignement Keele &amp; Hoge</translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="89"/>
        <source>applying Legendre alignment</source>
        <translation>application de l&apos;alignement Legendre</translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="97"/>
        <source>applying Zbinden alignment</source>
        <translation>application de l&apos;alignement Zbinden</translation>
    </message>
    <message>
        <location filename="optimizer.cpp" line="133"/>
        <source>applying bandpass box alignment</source>
        <translation>application de l&apos;alignement de l&apos;enceinte passe-bande</translation>
    </message>
    <message>
        <location filename="main.cpp" line="40"/>
        <source>Loudspeaker enclosure computation program.</source>
        <translation>Programme de calcul d&apos;enceintes acoustiques.</translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="383"/>
        <source>Spl: %1 dB</source>
        <translation>Spl : %1 dB</translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="384"/>
        <source>Fs: %1 Hz</source>
        <translation>Fs : %1 Hz</translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="385"/>
        <source>Qts: %1</source>
        <translation>Qts : %1</translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="386"/>
        <source>Vas: %1 L</source>
        <translation>Vas : %1 L</translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="387"/>
        <source>Dia: %1 m</source>
        <translation>Dia : %1 m</translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="388"/>
        <source>Xmax: %1 mm</source>
        <translation>Xmax : %1 mm</translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="389"/>
        <source>Z: %1 Ohm</source>
        <translation>Z : %1 Ohm</translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="390"/>
        <source>Re: %1 Ohm</source>
        <translation>Re : %1 Ohm</translation>
    </message>
    <message>
        <location filename="speaker.cpp" line="391"/>
        <source>Vc: %1</source>
        <translation>Vc : %1</translation>
    </message>
</context>
<context>
    <name>ScadDialog</name>
    <message>
        <location filename="scaddialog.cpp" line="20"/>
        <source>Loudspeaker margin (mm)</source>
        <translation>Marge du haut-parleur (mm)</translation>
    </message>
    <message>
        <location filename="scaddialog.cpp" line="24"/>
        <source>Wood thick (mm)</source>
        <translation>Épaisseur du bois (mm)</translation>
    </message>
    <message>
        <location filename="scaddialog.cpp" line="28"/>
        <source>Saw thick (mm)</source>
        <translation>Épaisseur de la scie (mm)</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="searchdialog.ui" line="23"/>
        <source>Loudspeaker parameter</source>
        <translation>Paramètre de haut-parleur</translation>
    </message>
    <message>
        <location filename="searchdialog.ui" line="36"/>
        <source>is between</source>
        <translation>est entre</translation>
    </message>
    <message>
        <location filename="searchdialog.ui" line="53"/>
        <source>and</source>
        <translation>et</translation>
    </message>
</context>
<context>
    <name>SpeakerDialog</name>
    <message>
        <location filename="speakerdialog.ui" line="14"/>
        <source>Loudspeaker</source>
        <translation>Haut-parleur</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="38"/>
        <source>Vendor</source>
        <translation>Constructeur</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="45"/>
        <source>speaker vendor name</source>
        <translation>nom du constructeur de haut-parleur</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="52"/>
        <source>Model</source>
        <translation>Modèle</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="59"/>
        <source>speaker name or reference number</source>
        <translation>nom ou numéro de référence du haut-parleur</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="66"/>
        <source>Fs (Hz)</source>
        <translation>Fs (Hz)</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="83"/>
        <source>Qts</source>
        <translation>Qts</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="97"/>
        <source>Vas (L)</source>
        <translation>Vas (L)</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="114"/>
        <source>Dia cutout (m)</source>
        <translation>Dia découpe (m)</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="131"/>
        <source>Z (Ohm)</source>
        <translation>Z (Ohm)</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="145"/>
        <source>Sd (m²)</source>
        <translation>Sd (m²)</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="159"/>
        <source>Re (Ohm)</source>
        <translation>Re (Ohm)</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="173"/>
        <source>Le (mH)</source>
        <translation>Le (mH)</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="187"/>
        <source>Xmax (mm)</source>
        <translation>Xmax (mm)</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="201"/>
        <source>Qms</source>
        <translation>Qms</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="215"/>
        <source>Qes</source>
        <translation>Qes</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="229"/>
        <source>Spl (dB)</source>
        <translation>Spl (dB)</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="246"/>
        <source>Pe (W)</source>
        <translation>Pe (W)</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="263"/>
        <source>BL (Tm)</source>
        <translation>BL (Tm)</translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="277"/>
        <source>Voice Coil (#)</source>
        <translation>Nb de voix (#)</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="main.cpp" line="43"/>
        <source>Project file to work on.</source>
        <translation>Fichier du projet sur lequel travailler.</translation>
    </message>
</context>
</TS>
